local LrTasks = import 'LrTasks'

API = require 'StudioCmsApi.lua'
Logger = require 'Logger.lua'
Sections = require 'Sections.lua'

Json = require 'json.lua'

-- Common shortcut

local exportServiceProvider = {}

exportServiceProvider.canExportVideo = false
exportServiceProvider.hidePrintResolution = true
exportServiceProvider.hideSections = { "exportLocation", "video" }
exportServiceProvider.sectionsForTopOfDialog = Sections.sectionsForTopOfDialog
exportServiceProvider.exportPresetFields = {
  { key = 'accountEmail', default = nil},
  { key = 'auth_token', default = nil}
}

function exportServiceProvider.startDialog(propertyTable)
  propertyTable.connected = false
  propertyTable.connecting = false
  -- propertyTable.accountEmail = ""
  propertyTable.auth_token = ""
  propertyTable.password = ""
  propertyTable.galleries = {}
  propertyTable.gallery_titles = {}
  propertyTable.selected_gallery_id = nil

  local function loadGalleries(pt, key, auth_token)
    Logger.outputToLog("Loading galleries")

    if LrTasks.canYield() then
      API.loadGalleries(pt)
    else
      LrTasks.startAsyncTask(function()
        API.loadGalleries(pt)
      end)
    end
  end

  loadGalleries(propertyTable, nil, propertyTable.auth_token)

  propertyTable:addObserver('auth_token', loadGalleries)
end

function exportServiceProvider.processRenderedPhotos(functionContext, exportContext)
  local exportSession = exportContext.exportSession

  -- Make a local reference to the export parameters.

  local exportSettings = assert(exportContext.propertyTable)

  local token = exportSettings.auth_token
  local gallery_id = exportSettings.selected_gallery_id or ''
  -- Get the # of photos.

  local nPhotos = exportSession:countRenditions()

  -- Set progress title.

  local progressScope = exportContext:configureProgress {
    title = nPhotos > 1
        and LOC("$$$/StudioCMS/Publish/Progress=Publishing ^1 photos to StudioCMs", nPhotos)
        or LOC "$$$/StudioCMS/Publish/Progress/One=Publishing one photo to StudioCMS",
  }

  for i, rendition in exportContext:renditions { stopIfCanceled = true } do
    -- Update progress scope.

    progressScope:setPortionComplete((i - 1) / nPhotos)

    -- Get next photo.

    local photo = rendition.photo

    if not rendition.wasSkipped then
      local success, pathOrMessage = rendition:waitForRender()

      -- Update progress scope again once we've got rendered photo.

      progressScope:setPortionComplete((i - 0.5) / nPhotos)

      -- Check for cancellation again after photo has been rendered.

      if progressScope:isCanceled() then break end

      if success then
        -- Build up common metadata for this photo.

        -- TODO: UPLOAD POHTO

        local result = API.upload(pathOrMessage, "image/jpeg", token, gallery_id)

        Logger.outputToLog(result)
      end
    else
      -- To get the skipped photo out of the to-republish bin.
      rendition:recordPublishedPhotoId(rendition.publishedPhotoId)
    end
  end

  progressScope:done()
end

return exportServiceProvider
