local LrBinding = import 'LrBinding'
local LrColor = import 'LrColor'
local LrTasks = import 'LrTasks'
local LrView = import 'LrView'

local API = require 'StudioCmsApi.lua'

local bind = LrView.bind
local share = LrView.share

local sections = {}

function sections.sectionsForTopOfDialog(vf, pt)
  return {
    {
      title = "StudioCMS Account",
      synposis = "Log in to your StudioCMS account",
      vf:view {
        vf:row {
          vf:static_text {
            title = "Account status: "
          },
          vf:static_text {
            title = bind {
              keys = {
                { key = "connected" },
              },
              operation = function(binding, values, fromTable)
                if values["connected"] then
                  return "connected"
                else
                  return "not connected"
                end
              end
            },
            text_color = bind {
              keys = {
                { key = "connected" },
              },
              operation = function(binding, values, fromTable)
                if values["connected"] then
                  return LrColor('green')
                else
                  return LrColor('red')
                end
              end
            }
          }
        },
        vf:spacer {
          height = 10
        },
        -- Email
        vf:row {
          fill_horizontal = 1,
          spacing = vf:label_spacing(),
          vf:static_text {
            title = "Email",
            alignment = 'left',
            width = share 'labelWidth'
          },
          vf:edit_field {
            value = bind 'accountEmail',
            immediate = true,
            fill_horizontal = 1,
          },
        },
        -- Password
        vf:row {
          fill_horizontal = 1,
          spacing = vf:label_spacing(),
          vf:static_text {
            title = "Password",
            alignment = 'left',
            width = share 'labelWidth'
          },
          vf:password_field {
            value = bind 'password',
            immediate = true,
            fill_horizontal = 1,
            height_in_lines = 1,
          },
        },
        vf:spacer {
          height = 10
        },
        vf:view {
          place = "overlapping",
          fill_horizontal = 1,
          vf:view {
            fill_horizontal = 1,
            visible = LrBinding.negativeOfKey("connected"),
            margin_bottom = 4,
            vf:row {
              fill_horizontal = 1,
              spacing = vf:label_spacing(),
              vf:push_button {
                title = LOC("$$$/StudioCMS/ExportDialog/Connect=Connect"),
                enabled = bind {
                  keys = {
                    { key = "connecting" },
                    { key = "accountEmail" },
                    { key = "password" },
                  },
                  operation = function(binding, values, fromTable)
                    if not values["connecting"] and values["accountEmail"] and #values["accountEmail"] > 0 and values["password"] and #values["password"] > 0 then
                      return true
                    else
                      return false
                    end
                  end
                },
                place_horizontal = 1,
                action = function()
                  API.connect(pt)
                end
              }
            }
          },
          vf:view {
            fill_horizontal = 1,
            visible = bind "connected",
            margin_bottom = 4,
            vf:row {
              fill_horizontal = 1,
              spacing = vf:label_spacing(),
              vf:push_button {
                title = LOC("$$$/StudioCMS/ExportDialog/Logout=Logout"),
                place_horizontal = 1,
                action = function()
                  logout(pt)
                end
              }
            }
          }
        }
      }
    },
    {
      title = "StudioCMS Gallery",
      synopsis = "Choose target StudioCMS gallery",
      vf:view {
        vf:row {
          vf:static_text {
            title = "Gallery:"
          },
          vf:popup_menu {
            value = bind 'selected_gallery_id',
            items = bind 'gallery_titles'
          },
          vf:push_button {
            title = "Clear",
            place_horizontal = 1,
            action = function()
              pt.selected_gallery_id = nil
            end
          },
          vf:push_button {
            title = "Refresh",
            place_horizontal = 1,
            action = function()
              if LrTasks.canYield() then
                API.loadGalleries(pt)
              else
                LrTasks.startAsyncTask(function()
                  API.loadGalleries(pt)
                end)
              end
            end
          },
        }
      }
    }
  }
end

return sections
